@@ -63,6 +63,17 @@ static struct gateway_data *find_gateway(int index, const char *gateway)
 	return NULL;
 }
 
+static void remove_gateway(int index, const char *gateway)
+{
+	struct gateway_data *data;
+
+	data = find_gateway(index, gateway);
+	if (data == NULL)
+		return;
+
+	gateway_list = g_slist_remove(gateway_list, data);
+}
+
 static int set_route(struct connman_element *element, const char *gateway)
 {
 	struct ifreq ifr;
@@ -300,9 +311,9 @@ static DBusMessage *get_properties(DBusConnection *conn,
 	struct connman_element *element = data;
 	DBusMessage *reply;
 	DBusMessageIter array, dict;
-	connman_uint8_t strength = 0;
+	connman_uint8_t strength;
 	const char *device, *network;
-	const char *type = NULL;
+	const char *type;
 
 	DBG("conn %p", conn);
 
@@ -321,13 +332,12 @@ static DBusMessage *get_properties(DBusConnection *conn,
 			DBUS_TYPE_STRING_AS_STRING DBUS_TYPE_VARIANT_AS_STRING
 			DBUS_DICT_ENTRY_END_CHAR_AS_STRING, &dict);
 
-	connman_element_get_static_property(element, "Type", &type);
-
+	type = connman_element_get_string(element, "Type");
 	if (type != NULL)
 		connman_dbus_dict_append_variant(&dict, "Type",
 						DBUS_TYPE_STRING, &type);
 
-	connman_element_get_static_property(element, "Strength", &strength);
+	strength = connman_element_get_uint8(element, "Strength");
 	if (strength > 0)
 		connman_dbus_dict_append_variant(&dict, "Strength",
 						DBUS_TYPE_BYTE, &strength);
@@ -339,12 +349,12 @@ static DBusMessage *get_properties(DBusConnection *conn,
 	connman_dbus_dict_append_variant(&dict, "Default",
 					DBUS_TYPE_BOOLEAN, &element->enabled);
 
-	device = __connman_element_get_device(element);
+	device = __connman_element_get_device_path(element);
 	if (device != NULL)
 		connman_dbus_dict_append_variant(&dict, "Device",
 					DBUS_TYPE_OBJECT_PATH, &device);
 
-	network = __connman_element_get_network(element);
+	network = __connman_element_get_network_path(element);
 	if (network != NULL)
 		connman_dbus_dict_append_variant(&dict, "Network",
 					DBUS_TYPE_OBJECT_PATH, &network);
@@ -457,6 +467,7 @@ static void unregister_interface(struct connman_element *element)
 
 static int connection_probe(struct connman_element *element)
 {
+	struct connman_service *service;
 	const char *gateway = NULL;
 
 	DBG("element %p name %s", element, element->name);
@@ -475,6 +486,10 @@ static int connection_probe(struct connman_element *element)
 	if (register_interface(element) < 0)
 		return -ENODEV;
 
+	service = __connman_element_get_service(element);
+	__connman_service_indicate_state(service,
+					CONNMAN_SERVICE_STATE_READY);
+
 	if (gateway == NULL)
 		return 0;
 
@@ -499,10 +514,15 @@ done:
 
 static void connection_remove(struct connman_element *element)
 {
+	struct connman_service *service;
 	const char *gateway = NULL;
 
 	DBG("element %p name %s", element, element->name);
 
+	service = __connman_element_get_service(element);
+	__connman_service_indicate_state(service,
+					CONNMAN_SERVICE_STATE_DISCONNECT);
+
 	unregister_interface(element);
 
 	connman_element_get_value(element,
@@ -513,6 +533,8 @@ static void connection_remove(struct connman_element *element)
 	if (gateway == NULL)
 		return;
 
+	remove_gateway(element->index, gateway);
+
 	connman_element_set_enabled(element, FALSE);
 	emit_default_signal(element);
 
